@@ -289,6 +289,7 @@ struct _GdkWindowObject
   guint guffaw_gravity : 1;
   guint input_only : 1;
   guint modal_hint : 1;
+  guint composited : 1;
   
   guint destroyed : 2;
 
@@ -297,6 +298,8 @@ struct _GdkWindowObject
   guint shaped : 1;
   
   GdkEventMask event_mask;
+
+  guint update_and_descendants_freeze_count;
 };
 
 struct _GdkWindowObjectClass
@@ -362,13 +365,13 @@ void          gdk_window_add_filter            (GdkWindow     *window,
 void          gdk_window_remove_filter         (GdkWindow     *window,
                                                 GdkFilterFunc  function,
                                                 gpointer       data);
-void          gdk_window_scroll                (GdkWindow *window,
-                                                gint       dx,
-                                                gint       dy);
-void	      gdk_window_move_region           (GdkWindow *window,
-						GdkRegion *region,
-						gint       dx,
-						gint       dy);
+void          gdk_window_scroll                (GdkWindow     *window,
+                                                gint           dx,
+                                                gint           dy);
+void	      gdk_window_move_region           (GdkWindow       *window,
+						const GdkRegion *region,
+						gint             dx,
+						gint             dy);
 
 /* 
  * This allows for making shaped (partially transparent) windows
@@ -376,14 +379,14 @@ void	      gdk_window_move_region           (GdkWindow *window,
  *  The shape_mask can be the mask
  *  from gdk_pixmap_create_from_xpm.   Stefan Wille
  */
-void gdk_window_shape_combine_mask  (GdkWindow	    *window,
-                                     GdkBitmap	    *mask,
-                                     gint	     x,
-                                     gint	     y);
-void gdk_window_shape_combine_region (GdkWindow	    *window,
-                                      GdkRegion     *shape_region,
-                                      gint	     offset_x,
-                                      gint	     offset_y);
+void gdk_window_shape_combine_mask  (GdkWindow	      *window,
+                                     GdkBitmap	      *mask,
+                                     gint	       x,
+                                     gint	       y);
+void gdk_window_shape_combine_region (GdkWindow	      *window,
+                                      const GdkRegion *shape_region,
+                                      gint	       offset_x,
+                                      gint	       offset_y);
 
 /*
  * This routine allows you to quickly take the shapes of all the child windows
@@ -394,6 +397,9 @@ void gdk_window_shape_combine_region (GdkWindow	    *window,
  */
 void gdk_window_set_child_shapes (GdkWindow *window);
 
+void gdk_window_set_composited   (GdkWindow *window,
+                                  gboolean   composited);
+
 /*
  * This routine allows you to merge (ie ADD) child shapes to your
  * own window's shape keeping its current shape and ADDING the child
@@ -401,18 +407,18 @@ void gdk_window_set_child_shapes (GdkWindow *window);
  * 
  * - Raster
  */
-void gdk_window_merge_child_shapes (GdkWindow *window);
+void gdk_window_merge_child_shapes         (GdkWindow       *window);
 
-void gdk_window_input_shape_combine_mask   (GdkWindow *window,
-					    GdkBitmap *mask,
-					    gint       x,
-					    gint       y);
-void gdk_window_input_shape_combine_region (GdkWindow *window,
-                                            GdkRegion *shape_region,
-                                            gint       offset_x,
-                                            gint       offset_y);
-void gdk_window_set_child_input_shapes     (GdkWindow *window);
-void gdk_window_merge_child_input_shapes   (GdkWindow *window);
+void gdk_window_input_shape_combine_mask   (GdkWindow       *window,
+					    GdkBitmap       *mask,
+					    gint             x,
+					    gint             y);
+void gdk_window_input_shape_combine_region (GdkWindow       *window,
+                                            const GdkRegion *shape_region,
+                                            gint             offset_x,
+                                            gint             offset_y);
+void gdk_window_set_child_input_shapes     (GdkWindow       *window);
+void gdk_window_merge_child_input_shapes   (GdkWindow       *window);
 
 
 /*
@@ -469,16 +475,16 @@ void gdk_window_set_skip_pager_hint   (GdkWindow *window,
 void gdk_window_set_urgency_hint      (GdkWindow *window,
 				       gboolean   urgent);
 
-void          gdk_window_set_geometry_hints (GdkWindow        *window,
-					     GdkGeometry      *geometry,
-					     GdkWindowHints    geom_mask);
-void          gdk_set_sm_client_id         (const gchar *sm_client_id);
+void          gdk_window_set_geometry_hints (GdkWindow          *window,
+					     const GdkGeometry  *geometry,
+					     GdkWindowHints      geom_mask);
+void          gdk_set_sm_client_id          (const gchar        *sm_client_id);
 
-void	      gdk_window_begin_paint_rect   (GdkWindow    *window,
-					     GdkRectangle *rectangle);
-void	      gdk_window_begin_paint_region (GdkWindow    *window,
-					     GdkRegion    *region);
-void	      gdk_window_end_paint          (GdkWindow    *window);
+void	      gdk_window_begin_paint_rect   (GdkWindow          *window,
+					     const GdkRectangle *rectangle);
+void	      gdk_window_begin_paint_region (GdkWindow          *window,
+					     const GdkRegion    *region);
+void	      gdk_window_end_paint          (GdkWindow          *window);
 
 void	      gdk_window_set_title	   (GdkWindow	  *window,
 					    const gchar	  *title);
@@ -586,14 +592,14 @@ void gdk_window_begin_move_drag   (GdkWindow     *window,
                                    guint32        timestamp);
 
 /* Interface for dirty-region queueing */
-void       gdk_window_invalidate_rect           (GdkWindow    *window,
-					         GdkRectangle *rect,
-					         gboolean      invalidate_children);
-void       gdk_window_invalidate_region         (GdkWindow    *window,
-					         GdkRegion    *region,
-					         gboolean      invalidate_children);
-void       gdk_window_invalidate_maybe_recurse  (GdkWindow *window,
-						 GdkRegion *region,
+void       gdk_window_invalidate_rect           (GdkWindow          *window,
+					         const GdkRectangle *rect,
+					         gboolean            invalidate_children);
+void       gdk_window_invalidate_region         (GdkWindow          *window,
+					         const GdkRegion    *region,
+					         gboolean            invalidate_children);
+void       gdk_window_invalidate_maybe_recurse  (GdkWindow          *window,
+						 const GdkRegion    *region,
 						 gboolean (*child_func) (GdkWindow *, gpointer),
 						 gpointer   user_data);
 GdkRegion *gdk_window_get_update_area     (GdkWindow    *window);
@@ -601,6 +607,9 @@ GdkRegion *gdk_window_get_update_area     (GdkWindow    *window);
 void       gdk_window_freeze_updates      (GdkWindow    *window);
 void       gdk_window_thaw_updates        (GdkWindow    *window);
 
+void       gdk_window_freeze_toplevel_updates_libgtk_only (GdkWindow *window);
+void       gdk_window_thaw_toplevel_updates_libgtk_only   (GdkWindow *window);
+
 void       gdk_window_process_all_updates (void);
 void       gdk_window_process_updates     (GdkWindow    *window,
 					   gboolean      update_children);
