@@ -156,6 +156,9 @@ void gdk_x11_display_broadcast_startup_message (GdkDisplay *display,
 gboolean gdk_x11_screen_supports_net_wm_hint (GdkScreen *screen,
 					      GdkAtom    property);
 
+XID      gdk_x11_screen_get_monitor_output   (GdkScreen *screen,
+                                              gint       monitor_num);
+
 #ifndef GDK_MULTIHEAD_SAFE
 gpointer      gdk_xid_table_lookup   (XID              xid);
 gboolean      gdk_net_wm_supports    (GdkAtom    property);
