@@ -130,8 +130,7 @@ gtk_file_filter_finalize (GObject  *object)
   g_slist_foreach (filter->rules, (GFunc)filter_rule_free, NULL);
   g_slist_free (filter->rules);
 
-  if (filter->name)
-    g_free (filter->name);
+  g_free (filter->name);
 
   G_OBJECT_CLASS (gtk_file_filter_parent_class)->finalize (object);
 }
@@ -145,11 +144,10 @@ gtk_file_filter_finalize (GObject  *object)
  * gtk_file_filter_add_mime_type(), gtk_file_filter_add_pattern(),
  * or gtk_file_filter_add_custom(). To create a filter
  * that accepts any file, use:
- *
- * <informalexample><programlisting>
- * GtkFileFilter *filter = gtk_file_filter_new (<!-- -->);
+ * |[
+ * GtkFileFilter *filter = gtk_file_filter_new ();
  * gtk_file_filter_add_pattern (filter, "*");
- * </programlisting></informalexample>
+ * ]|
  * 
  * Return value: a new #GtkFileFilter
  * 
@@ -179,8 +177,7 @@ gtk_file_filter_set_name (GtkFileFilter *filter,
 {
   g_return_if_fail (GTK_IS_FILE_FILTER (filter));
   
-  if (filter->name)
-    g_free (filter->name);
+  g_free (filter->name);
 
   filter->name = g_strdup (name);
 }
