@@ -1890,10 +1890,10 @@ gtk_list_store_has_default_sort_func (GtkTreeSortable *sortable)
  * Calling
  * <literal>gtk_list_store_insert_with_values(list_store, iter, position...)</literal> 
  * has the same effect as calling 
- * <informalexample><programlisting>
+ * |[
  * gtk_list_store_insert (list_store, iter, position);
  * gtk_list_store_set (list_store, iter, ...);
- * </programlisting></informalexample>
+ * ]|
  * with the difference that the former will only emit a row_inserted signal,
  * while the latter will emit row_inserted, row_changed and, if the list store
  * is sorted, rows_reordered. Since emitting the rows_reordered signal
@@ -2072,11 +2072,8 @@ list_store_start_element (GMarkupParseContext *context,
       int i, id = -1;
 
       if (data->row_column >= data->n_columns)
-        {
-	  g_set_error (error, data->error_quark, 0,
-	  	       "Too many columns, maximum is %d\n", data->n_columns - 1);
-          return;
-        }
+	g_set_error (error, data->error_quark, 0,
+		     "Too many columns, maximum is %d\n", data->n_columns - 1);
 
       for (i = 0; names[i]; i++)
 	if (strcmp (names[i], "id") == 0)
@@ -2084,26 +2081,13 @@ list_store_start_element (GMarkupParseContext *context,
 	    errno = 0;
 	    id = atoi (values[i]);
 	    if (errno)
-              {
-	        g_set_error (error, data->error_quark, 0,
-			     "the id tag %s could not be converted to an integer",
-			     values[i]);
-                return;
-              }
-	    if (id < 0 || id >= data->n_columns)
-              {
-                g_set_error (error, data->error_quark, 0,
-                             "id value %d out of range", id);
-                return;
-              }
+	      g_set_error (error, data->error_quark, 0,
+			   "the id tag %s could not be converted to an integer", values[i]);
 	  }
 
       if (id == -1)
-        {
-	  g_set_error (error, data->error_quark, 0,
-	  	       "<col> needs an id attribute");
-          return;
-        }
+	g_set_error (error, data->error_quark, 0,
+		     "<col> needs an id attribute");
 
       data->columns[data->row_column] = id;
       data->row_column++;
@@ -2205,7 +2189,7 @@ list_store_text (GMarkupParseContext *context,
   gint i;
   GError *tmp_error = NULL;
   gchar *string;
-
+  
   if (!data->is_data)
     return;
 
