@@ -36,7 +36,6 @@
 #include "gtkiconfactory.h"
 #include "gtkimage.h"
 #include "gtktreeselection.h"
-#include "gtkmessagedialog.h"
 #include "gtknotebook.h"
 #include "gtkscrolledwindow.h"
 #include "gtkcombobox.h"
@@ -57,9 +56,6 @@
 #include "gtkprinteroptionwidget.h"
 #include "gtkalias.h"
 
-#include "gtkmessagedialog.h"
-#include "gtkbutton.h"
-
 #define EXAMPLE_PAGE_AREA_SIZE 140
 
 #define GTK_PRINT_UNIX_DIALOG_GET_PRIVATE(o)  \
@@ -195,7 +191,6 @@ struct GtkPrintUnixDialogPrivate
   GList *print_backends;
   
   GtkPrinter *current_printer;
-  GtkPrinter *request_details_printer;
   guint request_details_tag;
   GtkPrinterOptionSet *options;
   gulong options_changed_handler;
@@ -278,127 +273,6 @@ gtk_print_unix_dialog_class_init (GtkPrintUnixDialogClass *class)
   g_type_class_add_private (class, sizeof (GtkPrintUnixDialogPrivate));  
 }
 
-/* Returns a toplevel GtkWindow, or NULL if none */
-static GtkWindow *
-get_toplevel (GtkWidget *widget)
-{
-  GtkWidget *toplevel = NULL;
-
-  toplevel = gtk_widget_get_toplevel (widget);
-  if (!GTK_WIDGET_TOPLEVEL (toplevel))
-    return NULL;
-  else
-    return GTK_WINDOW (toplevel);
-}
-
-static void
-add_custom_button_to_dialog (GtkDialog   *dialog,
-                             const gchar *mnemonic_label,
-                             const gchar *stock_id,
-                             gint         response_id)
-{
-  GtkWidget *button = NULL;
-
-  button = gtk_button_new_with_mnemonic (mnemonic_label);
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
-  gtk_button_set_image (GTK_BUTTON (button),
-                        gtk_image_new_from_stock (stock_id,
-                                                  GTK_ICON_SIZE_BUTTON));
-  gtk_widget_show (button);
-
-  gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, response_id);
-}
-
-/* Presents an overwrite confirmation dialog ("print to file" backend).
- */
-static gboolean
-overwrite_confirmation_dialog (GtkPrintUnixDialog *print_dialog,
-                               gint                print_dialog_response_id,
-                               gpointer            data)
-{
-  GtkPrintUnixDialogPrivate *priv = print_dialog->priv;
-  GtkPrinterOption          *option = NULL;
-  GtkPrinter                *printer = NULL;
-  GtkWindow                 *toplevel = NULL;
-  GtkWidget                 *dialog = NULL;
-  gchar                     *filename = NULL;
-  gchar                     *basename = NULL;
-  gchar                     *dirname = NULL;
-  int                        response;
-
-  if (print_dialog != NULL && print_dialog_response_id == GTK_RESPONSE_OK)
-    {
-      printer = gtk_print_unix_dialog_get_selected_printer (print_dialog);
-
-      if (printer != NULL && gtk_printer_is_virtual (printer))
-        {
-          option = gtk_printer_option_set_lookup (priv->options,
-                                                  "gtk-main-page-custom-input");
-
-          if (option != NULL &&
-              option->type == GTK_PRINTER_OPTION_TYPE_FILESAVE)
-            {
-              filename = g_filename_from_uri (option->value, NULL, NULL);
-
-              if (filename != NULL &&
-                  g_file_test (filename, G_FILE_TEST_EXISTS))
-                {
-                  toplevel = get_toplevel (GTK_WIDGET (print_dialog));
-
-                  basename = g_path_get_basename (filename);
-                  dirname = g_path_get_dirname (filename);
-
-                  dialog = gtk_message_dialog_new (toplevel,
-                                                   GTK_DIALOG_MODAL |
-                                                   GTK_DIALOG_DESTROY_WITH_PARENT,
-                                                   GTK_MESSAGE_QUESTION,
-                                                   GTK_BUTTONS_NONE,
-                                                   _("A file named \"%s\" already exists.  Do you want to replace it?"),
-                                                   basename);
-
-                  gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-                                                            _("The file already exists in \"%s\".  Replacing it will "
-                                                            "overwrite its contents."),
-                                                            dirname);
-
-                  gtk_dialog_add_button (GTK_DIALOG (dialog),
-                                         GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
-                  add_custom_button_to_dialog (GTK_DIALOG (dialog),
-                                               _("_Replace"),
-                                               GTK_STOCK_PRINT,
-                                               GTK_RESPONSE_ACCEPT);
-                  gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
-                                                           GTK_RESPONSE_ACCEPT,
-                                                           GTK_RESPONSE_CANCEL,
-                                                           -1);
-                  gtk_dialog_set_default_response (GTK_DIALOG (dialog),
-                                                   GTK_RESPONSE_ACCEPT);
-
-                  if (toplevel->group)
-                    gtk_window_group_add_window (toplevel->group,
-                                                 GTK_WINDOW (dialog));
-
-                  response = gtk_dialog_run (GTK_DIALOG (dialog));
-
-                  gtk_widget_destroy (dialog);
-
-                  if (response != GTK_RESPONSE_ACCEPT)
-                    {
-                      g_signal_stop_emission_by_name (print_dialog, "response");
-                      return TRUE;
-                    }
-
-                  g_free (dirname);
-                  g_free (basename);
-                }
-
-              g_free (filename);
-            }
-        }
-    }
-  return FALSE;
-}
-
 static void
 gtk_print_unix_dialog_init (GtkPrintUnixDialog *dialog)
 {
@@ -415,11 +289,6 @@ gtk_print_unix_dialog_init (GtkPrintUnixDialog *dialog)
 		    (GCallback) gtk_print_unix_dialog_destroy, 
 		    NULL);
 
-  g_signal_connect (dialog,
-                    "response",
-                    (GCallback) overwrite_confirmation_dialog,
-                    NULL);
-
   priv->preview_button = gtk_button_new_from_stock (GTK_STOCK_PRINT_PREVIEW);
   gtk_widget_show (priv->preview_button);
    
@@ -430,6 +299,11 @@ gtk_print_unix_dialog_init (GtkPrintUnixDialog *dialog)
 			  GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
 			  GTK_STOCK_PRINT, GTK_RESPONSE_OK,
                           NULL);
+  gtk_dialog_set_alternative_button_order (GTK_DIALOG (dialog),
+					   GTK_RESPONSE_APPLY,
+					   GTK_RESPONSE_OK,
+					   GTK_RESPONSE_CANCEL,
+					   -1);
 
   gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
   gtk_dialog_set_response_sensitive (GTK_DIALOG (dialog), GTK_RESPONSE_OK, FALSE);
@@ -444,21 +318,6 @@ gtk_print_unix_dialog_destroy (GtkPrintUnixDialog *dialog)
   clear_per_printer_ui (dialog);  
 }
 
-static void
-disconnect_printer_details_request (GtkPrintUnixDialog *dialog)
-{
-  GtkPrintUnixDialogPrivate *priv = dialog->priv;
-
-  if (priv->request_details_tag)
-    {
-      g_signal_handler_disconnect (priv->request_details_printer,
-                                   priv->request_details_tag);
-      priv->request_details_tag = 0;
-      g_object_unref (priv->request_details_printer);
-      priv->request_details_printer = NULL;
-    }
-}
-
 static void
 gtk_print_unix_dialog_finalize (GObject *object)
 {
@@ -468,8 +327,13 @@ gtk_print_unix_dialog_finalize (GObject *object)
   GList *node;
 
   unschedule_idle_mark_conflicts (dialog);
-  disconnect_printer_details_request (dialog);
 
+  if (priv->request_details_tag)
+    {
+      g_source_remove (priv->request_details_tag);
+      priv->request_details_tag = 0;
+    }
+  
   if (priv->current_printer)
     {
       g_object_unref (priv->current_printer);
@@ -1363,7 +1227,7 @@ printer_details_acquired (GtkPrinter         *printer,
 {
   GtkPrintUnixDialogPrivate *priv = dialog->priv;
 
-  disconnect_printer_details_request (dialog);
+  priv->request_details_tag = 0;
   
   if (success)
     {
@@ -1390,9 +1254,13 @@ selected_printer_changed (GtkTreeSelection   *selection,
       g_free (priv->waiting_for_printer);
       priv->waiting_for_printer = NULL;
     }
-
-  disconnect_printer_details_request (dialog);
-
+  
+  if (priv->request_details_tag)
+    {
+      g_source_remove (priv->request_details_tag);
+      priv->request_details_tag = 0;
+    }
+  
   printer = NULL;
   if (gtk_tree_selection_get_selected (selection, NULL, &filter_iter))
     {
@@ -1411,9 +1279,8 @@ selected_printer_changed (GtkTreeSelection   *selection,
       priv->request_details_tag =
 	g_signal_connect (printer, "details-acquired",
 			  G_CALLBACK (printer_details_acquired), dialog);
-      /* take the reference */
-      priv->request_details_printer = printer;
       gtk_printer_request_details (printer);
+      g_object_unref (printer);
       return;
     }
   
@@ -1679,18 +1546,18 @@ create_main_page (GtkPrintUnixDialog *dialog)
   table = gtk_table_new (3, 2, FALSE);
   gtk_table_set_row_spacings (GTK_TABLE (table), 6);
   gtk_table_set_col_spacings (GTK_TABLE (table), 12);
-  frame = wrap_in_frame (_("Print Pages"), table);
+  frame = wrap_in_frame (_("Range"), table);
   gtk_box_pack_start (GTK_BOX (hbox), frame, TRUE, TRUE, 0);
   gtk_widget_show (table);
 
-  radio = gtk_radio_button_new_with_mnemonic (NULL, _("_All"));
+  radio = gtk_radio_button_new_with_mnemonic (NULL, _("_All Pages"));
   priv->all_pages_radio = radio;
   gtk_widget_show (radio);
   gtk_table_attach (GTK_TABLE (table), radio,
 		    0, 2, 0, 1,  GTK_FILL, 0,
 		    0, 0);
   radio = gtk_radio_button_new_with_mnemonic (gtk_radio_button_get_group (GTK_RADIO_BUTTON (radio)),
-					      _("C_urrent"));
+					      _("C_urrent Page"));
   if (priv->current_page == -1)
     gtk_widget_set_sensitive (radio, FALSE);    
   priv->current_page_radio = radio;
@@ -1699,7 +1566,7 @@ create_main_page (GtkPrintUnixDialog *dialog)
 		    0, 2, 1, 2,  GTK_FILL, 0,
 		    0, 0);
  
-  radio = gtk_radio_button_new_with_mnemonic (gtk_radio_button_get_group (GTK_RADIO_BUTTON (radio)), _("Ra_nge"));
+  radio = gtk_radio_button_new_with_mnemonic (gtk_radio_button_get_group (GTK_RADIO_BUTTON (radio)), _("Pag_es:"));
   gtk_widget_set_tooltip_text (radio, _("Specify one or more page ranges,\n e.g. 1-3,7,11"));
  
   priv->page_range_radio = radio;
