@@ -32,9 +32,7 @@
 #include <gtk/gtkenums.h>
 #include <pango/pango.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 #define GTK_TYPE_STYLE              (gtk_style_get_type ())
 #define GTK_STYLE(object)           (G_TYPE_CHECK_INSTANCE_CAST ((object), GTK_TYPE_STYLE, GtkStyle))
@@ -429,7 +427,7 @@ GType     gtk_style_get_type                 (void) G_GNUC_CONST;
 GtkStyle* gtk_style_new			     (void);
 GtkStyle* gtk_style_copy		     (GtkStyle	   *style);
 GtkStyle* gtk_style_attach		     (GtkStyle	   *style,
-					      GdkWindow	   *window);
+					      GdkWindow	   *window) G_GNUC_WARN_UNUSED_RESULT;
 void	  gtk_style_detach		     (GtkStyle	   *style);
 
 #ifndef GTK_DISABLE_DEPRECATED
@@ -448,14 +446,18 @@ void	  gtk_style_apply_default_background (GtkStyle	   *style,
 					      GdkWindow	   *window,
 					      gboolean	    set_bg,
 					      GtkStateType  state_type, 
-					      GdkRectangle *area, 
+					      const GdkRectangle *area,
 					      gint	    x, 
 					      gint	    y, 
 					      gint	    width, 
 					      gint	    height);
 
-GtkIconSet* gtk_style_lookup_icon_set (GtkStyle            *style,
-                                       const gchar         *stock_id);
+GtkIconSet* gtk_style_lookup_icon_set        (GtkStyle     *style,
+                                              const gchar  *stock_id);
+gboolean    gtk_style_lookup_color           (GtkStyle     *style,
+                                              const gchar  *color_name,
+                                              GdkColor     *color);
+
 GdkPixbuf*  gtk_style_render_icon     (GtkStyle            *style,
                                        const GtkIconSource *source,
                                        GtkTextDirection     direction,
@@ -463,6 +465,7 @@ GdkPixbuf*  gtk_style_render_icon     (GtkStyle            *style,
                                        GtkIconSize          size,
                                        GtkWidget           *widget,
                                        const gchar         *detail);
+
 #ifndef GTK_DISABLE_DEPRECATED
 void gtk_draw_hline      (GtkStyle        *style,
 			  GdkWindow       *window,
@@ -627,234 +630,234 @@ void gtk_draw_resize_grip (GtkStyle       *style,
                            gint            height);
 #endif /* GTK_DISABLE_DEPRECATED */
 
-void gtk_paint_hline      (GtkStyle        *style,
-			   GdkWindow       *window,
-			   GtkStateType     state_type,
-			   GdkRectangle    *area,
-			   GtkWidget       *widget,
-			   const gchar     *detail,
-			   gint             x1,
-			   gint             x2,
-			   gint             y);
-void gtk_paint_vline      (GtkStyle        *style,
-			   GdkWindow       *window,
-			   GtkStateType     state_type,
-			   GdkRectangle    *area,
-			   GtkWidget       *widget,
-			   const gchar     *detail,
-			   gint             y1_,
-			   gint             y2_,
-			   gint             x);
-void gtk_paint_shadow     (GtkStyle        *style,
-			   GdkWindow       *window,
-			   GtkStateType     state_type,
-			   GtkShadowType    shadow_type,
-			   GdkRectangle    *area,
-			   GtkWidget       *widget,
-			   const gchar     *detail,
-			   gint             x,
-			   gint             y,
-			   gint             width,
-			   gint             height);
-void gtk_paint_polygon    (GtkStyle        *style,
-			   GdkWindow       *window,
-			   GtkStateType     state_type,
-			   GtkShadowType    shadow_type,
-			   GdkRectangle    *area,
-			   GtkWidget       *widget,
-			   const gchar     *detail,
-			   GdkPoint        *points,
-			   gint             npoints,
-			   gboolean         fill);
-void gtk_paint_arrow      (GtkStyle        *style,
-			   GdkWindow       *window,
-			   GtkStateType     state_type,
-			   GtkShadowType    shadow_type,
-			   GdkRectangle    *area,
-			   GtkWidget       *widget,
-			   const gchar     *detail,
-			   GtkArrowType     arrow_type,
-			   gboolean         fill,
-			   gint             x,
-			   gint             y,
-			   gint             width,
-			   gint             height);
-void gtk_paint_diamond    (GtkStyle        *style,
-			   GdkWindow       *window,
-			   GtkStateType     state_type,
-			   GtkShadowType    shadow_type,
-			   GdkRectangle    *area,
-			   GtkWidget       *widget,
-			   const gchar     *detail,
-			   gint             x,
-			   gint             y,
-			   gint             width,
-			   gint             height);
-void gtk_paint_box        (GtkStyle        *style,
-			   GdkWindow       *window,
-			   GtkStateType     state_type,
-			   GtkShadowType    shadow_type,
-			   GdkRectangle    *area,
-			   GtkWidget       *widget,
-			   const gchar     *detail,
-			   gint             x,
-			   gint             y,
-			   gint             width,
-			   gint             height);
-void gtk_paint_flat_box   (GtkStyle        *style,
-			   GdkWindow       *window,
-			   GtkStateType     state_type,
-			   GtkShadowType    shadow_type,
-			   GdkRectangle    *area,
-			   GtkWidget       *widget,
-			   const gchar     *detail,
-			   gint             x,
-			   gint             y,
-			   gint             width,
-			   gint             height);
-void gtk_paint_check      (GtkStyle        *style,
-			   GdkWindow       *window,
-			   GtkStateType     state_type,
-			   GtkShadowType    shadow_type,
-			   GdkRectangle    *area,
-			   GtkWidget       *widget,
-			   const gchar     *detail,
-			   gint             x,
-			   gint             y,
-			   gint             width,
-			   gint             height);
-void gtk_paint_option     (GtkStyle        *style,
-			   GdkWindow       *window,
-			   GtkStateType     state_type,
-			   GtkShadowType    shadow_type,
-			   GdkRectangle    *area,
-			   GtkWidget       *widget,
-			   const gchar     *detail,
-			   gint             x,
-			   gint             y,
-			   gint             width,
-			   gint             height);
-void gtk_paint_tab        (GtkStyle        *style,
-			   GdkWindow       *window,
-			   GtkStateType     state_type,
-			   GtkShadowType    shadow_type,
-			   GdkRectangle    *area,
-			   GtkWidget       *widget,
-			   const gchar     *detail,
-			   gint             x,
-			   gint             y,
-			   gint             width,
-			   gint             height);
-void gtk_paint_shadow_gap (GtkStyle        *style,
-			   GdkWindow       *window,
-			   GtkStateType     state_type,
-			   GtkShadowType    shadow_type,
-			   GdkRectangle    *area,
-			   GtkWidget       *widget,
-			   gchar           *detail,
-			   gint             x,
-			   gint             y,
-			   gint             width,
-			   gint             height,
-			   GtkPositionType  gap_side,
-			   gint             gap_x,
-			   gint             gap_width);
-void gtk_paint_box_gap    (GtkStyle        *style,
-			   GdkWindow       *window,
-			   GtkStateType     state_type,
-			   GtkShadowType    shadow_type,
-			   GdkRectangle    *area,
-			   GtkWidget       *widget,
-			   gchar           *detail,
-			   gint             x,
-			   gint             y,
-			   gint             width,
-			   gint             height,
-			   GtkPositionType  gap_side,
-			   gint             gap_x,
-			   gint             gap_width);
-void gtk_paint_extension  (GtkStyle        *style,
-			   GdkWindow       *window,
-			   GtkStateType     state_type,
-			   GtkShadowType    shadow_type,
-			   GdkRectangle    *area,
-			   GtkWidget       *widget,
-			   gchar           *detail,
-			   gint             x,
-			   gint             y,
-			   gint             width,
-			   gint             height,
-			   GtkPositionType  gap_side);
-void gtk_paint_focus      (GtkStyle        *style,
-			   GdkWindow       *window,
-			   GtkStateType     state_type,
-			   GdkRectangle    *area,
-			   GtkWidget       *widget,
-			   const gchar     *detail,
-			   gint             x,
-			   gint             y,
-			   gint             width,
-			   gint             height);
-void gtk_paint_slider     (GtkStyle        *style,
-			   GdkWindow       *window,
-			   GtkStateType     state_type,
-			   GtkShadowType    shadow_type,
-			   GdkRectangle    *area,
-			   GtkWidget       *widget,
-			   const gchar     *detail,
-			   gint             x,
-			   gint             y,
-			   gint             width,
-			   gint             height,
-			   GtkOrientation   orientation);
-void gtk_paint_handle     (GtkStyle        *style,
-			   GdkWindow       *window,
-			   GtkStateType     state_type,
-			   GtkShadowType    shadow_type,
-			   GdkRectangle    *area,
-			   GtkWidget       *widget,
-			   const gchar     *detail,
-			   gint             x,
-			   gint             y,
-			   gint             width,
-			   gint             height,
-			   GtkOrientation   orientation);
-void gtk_paint_expander   (GtkStyle        *style,
-                           GdkWindow       *window,
-                           GtkStateType     state_type,
-                           GdkRectangle    *area,
-                           GtkWidget       *widget,
-                           const gchar     *detail,
-                           gint             x,
-                           gint             y,
-			   GtkExpanderStyle expander_style);
-void gtk_paint_layout     (GtkStyle        *style,
-                           GdkWindow       *window,
-                           GtkStateType     state_type,
-			   gboolean         use_text,
-                           GdkRectangle    *area,
-                           GtkWidget       *widget,
-                           const gchar     *detail,
-                           gint             x,
-                           gint             y,
-                           PangoLayout     *layout);
-
-void gtk_paint_resize_grip (GtkStyle		*style,
-                            GdkWindow		*window,
-                            GtkStateType         state_type,
-                            GdkRectangle        *area,
-                            GtkWidget		*widget,
-                            const gchar		*detail,
-                            GdkWindowEdge        edge,
-                            gint                 x,
-                            gint                 y,
-                            gint                 width,
-                            gint           	 height);
+void gtk_paint_hline       (GtkStyle           *style,
+			    GdkWindow          *window,
+			    GtkStateType        state_type,
+			    const GdkRectangle *area,
+			    GtkWidget          *widget,
+			    const gchar        *detail,
+			    gint                x1,
+			    gint                x2,
+			    gint                y);
+void gtk_paint_vline       (GtkStyle           *style,
+			    GdkWindow          *window,
+			    GtkStateType        state_type,
+			    const GdkRectangle *area,
+			    GtkWidget          *widget,
+			    const gchar        *detail,
+			    gint                y1_,
+			    gint                y2_,
+			    gint                x);
+void gtk_paint_shadow      (GtkStyle           *style,
+			    GdkWindow          *window,
+			    GtkStateType        state_type,
+			    GtkShadowType       shadow_type,
+			    const GdkRectangle *area,
+			    GtkWidget          *widget,
+			    const gchar        *detail,
+			    gint                x,
+			    gint                y,
+			    gint                width,
+			    gint                height);
+void gtk_paint_polygon     (GtkStyle           *style,
+			    GdkWindow          *window,
+			    GtkStateType        state_type,
+			    GtkShadowType       shadow_type,
+			    const GdkRectangle *area,
+			    GtkWidget          *widget,
+			    const gchar        *detail,
+			    const GdkPoint     *points,
+			    gint                n_points,
+			    gboolean            fill);
+void gtk_paint_arrow       (GtkStyle           *style,
+			    GdkWindow          *window,
+			    GtkStateType        state_type,
+			    GtkShadowType       shadow_type,
+			    const GdkRectangle *area,
+			    GtkWidget          *widget,
+			    const gchar        *detail,
+			    GtkArrowType        arrow_type,
+			    gboolean            fill,
+			    gint                x,
+			    gint                y,
+			    gint                width,
+			    gint                height);
+void gtk_paint_diamond     (GtkStyle           *style,
+			    GdkWindow          *window,
+			    GtkStateType        state_type,
+			    GtkShadowType       shadow_type,
+			    const GdkRectangle *area,
+			    GtkWidget          *widget,
+			    const gchar        *detail,
+			    gint                x,
+			    gint                y,
+			    gint                width,
+			    gint                height);
+void gtk_paint_box         (GtkStyle           *style,
+			    GdkWindow          *window,
+			    GtkStateType        state_type,
+			    GtkShadowType       shadow_type,
+			    const GdkRectangle *area,
+			    GtkWidget          *widget,
+			    const gchar        *detail,
+			    gint                x,
+			    gint                y,
+			    gint                width,
+			    gint                height);
+void gtk_paint_flat_box    (GtkStyle           *style,
+			    GdkWindow          *window,
+			    GtkStateType        state_type,
+			    GtkShadowType       shadow_type,
+			    const GdkRectangle *area,
+			    GtkWidget          *widget,
+			    const gchar        *detail,
+			    gint                x,
+			    gint                y,
+			    gint                width,
+			    gint                height);
+void gtk_paint_check       (GtkStyle           *style,
+			    GdkWindow          *window,
+			    GtkStateType        state_type,
+			    GtkShadowType       shadow_type,
+			    const GdkRectangle *area,
+			    GtkWidget          *widget,
+			    const gchar        *detail,
+			    gint                x,
+			    gint                y,
+			    gint                width,
+			    gint                height);
+void gtk_paint_option      (GtkStyle           *style,
+			    GdkWindow          *window,
+			    GtkStateType        state_type,
+			    GtkShadowType       shadow_type,
+			    const GdkRectangle *area,
+			    GtkWidget          *widget,
+			    const gchar        *detail,
+			    gint                x,
+			    gint                y,
+			    gint                width,
+			    gint                height);
+void gtk_paint_tab         (GtkStyle           *style,
+			    GdkWindow          *window,
+			    GtkStateType        state_type,
+			    GtkShadowType       shadow_type,
+			    const GdkRectangle *area,
+			    GtkWidget          *widget,
+			    const gchar        *detail,
+			    gint                x,
+			    gint                y,
+			    gint                width,
+			    gint                height);
+void gtk_paint_shadow_gap  (GtkStyle           *style,
+			    GdkWindow          *window,
+			    GtkStateType        state_type,
+			    GtkShadowType       shadow_type,
+			    const GdkRectangle *area,
+			    GtkWidget          *widget,
+			    const gchar        *detail,
+			    gint                x,
+			    gint                y,
+			    gint                width,
+			    gint                height,
+			    GtkPositionType     gap_side,
+			    gint                gap_x,
+			    gint                gap_width);
+void gtk_paint_box_gap     (GtkStyle           *style,
+			    GdkWindow          *window,
+			    GtkStateType        state_type,
+			    GtkShadowType       shadow_type,
+			    const GdkRectangle *area,
+			    GtkWidget          *widget,
+			    const gchar        *detail,
+			    gint                x,
+			    gint                y,
+			    gint                width,
+			    gint                height,
+			    GtkPositionType     gap_side,
+			    gint                gap_x,
+			    gint                gap_width);
+void gtk_paint_extension   (GtkStyle           *style,
+			    GdkWindow          *window,
+			    GtkStateType        state_type,
+			    GtkShadowType       shadow_type,
+			    const GdkRectangle *area,
+			    GtkWidget          *widget,
+			    const gchar        *detail,
+			    gint                x,
+			    gint                y,
+			    gint                width,
+			    gint                height,
+			    GtkPositionType     gap_side);
+void gtk_paint_focus       (GtkStyle           *style,
+			    GdkWindow          *window,
+			    GtkStateType        state_type,
+			    const GdkRectangle *area,
+			    GtkWidget          *widget,
+			    const gchar        *detail,
+			    gint                x,
+			    gint                y,
+			    gint                width,
+			    gint                height);
+void gtk_paint_slider      (GtkStyle           *style,
+			    GdkWindow          *window,
+			    GtkStateType        state_type,
+			    GtkShadowType       shadow_type,
+			    const GdkRectangle *area,
+			    GtkWidget          *widget,
+			    const gchar        *detail,
+			    gint                x,
+			    gint                y,
+			    gint                width,
+			    gint                height,
+			    GtkOrientation      orientation);
+void gtk_paint_handle      (GtkStyle           *style,
+			    GdkWindow          *window,
+			    GtkStateType        state_type,
+			    GtkShadowType       shadow_type,
+			    const GdkRectangle *area,
+			    GtkWidget          *widget,
+			    const gchar        *detail,
+			    gint                x,
+			    gint                y,
+			    gint                width,
+			    gint                height,
+			    GtkOrientation      orientation);
+void gtk_paint_expander    (GtkStyle           *style,
+                            GdkWindow          *window,
+                            GtkStateType        state_type,
+                            const GdkRectangle *area,
+                            GtkWidget          *widget,
+                            const gchar        *detail,
+                            gint                x,
+                            gint                y,
+			    GtkExpanderStyle    expander_style);
+void gtk_paint_layout      (GtkStyle           *style,
+                            GdkWindow          *window,
+                            GtkStateType        state_type,
+			    gboolean            use_text,
+                            const GdkRectangle *area,
+                            GtkWidget          *widget,
+                            const gchar        *detail,
+                            gint                x,
+                            gint                y,
+                            PangoLayout        *layout);
+void gtk_paint_resize_grip (GtkStyle           *style,
+                            GdkWindow          *window,
+                            GtkStateType        state_type,
+                            const GdkRectangle *area,
+                            GtkWidget          *widget,
+                            const gchar        *detail,
+                            GdkWindowEdge       edge,
+                            gint                x,
+                            gint                y,
+                            gint                width,
+                            gint                height);
 
 
 GType      gtk_border_get_type (void) G_GNUC_CONST;
+GtkBorder *gtk_border_new      (void) G_GNUC_MALLOC;
 GtkBorder *gtk_border_copy     (const GtkBorder *border_);
-void       gtk_border_free (   GtkBorder       *border_);
+void       gtk_border_free     (GtkBorder       *border_);
 
 /* --- private API --- */
 const GValue* _gtk_style_peek_property_value (GtkStyle           *style,
@@ -862,40 +865,44 @@ const GValue* _gtk_style_peek_property_value (GtkStyle           *style,
 					      GParamSpec         *pspec,
 					      GtkRcPropertyParser parser);
 
-void _gtk_style_init_for_settings (GtkStyle    *style,
-				   GtkSettings *settings);
+void          _gtk_style_init_for_settings   (GtkStyle           *style,
+                                              GtkSettings        *settings);
+
+void          _gtk_style_shade               (const GdkColor     *a,
+                                              GdkColor           *b,
+                                              gdouble             k);
 
 /* deprecated */
 #ifndef GTK_DISABLE_DEPRECATED
 #define gtk_style_apply_default_pixmap(s,gw,st,a,x,y,w,h) gtk_style_apply_default_background (s,gw,1,st,a,x,y,w,h)
-void gtk_draw_string     (GtkStyle        *style,
-			  GdkWindow       *window,
-			  GtkStateType     state_type,
-			  gint             x,
-			  gint             y,
-			  const gchar     *string);
-void gtk_paint_string     (GtkStyle        *style,
-			   GdkWindow       *window,
-			   GtkStateType     state_type,
-			   GdkRectangle    *area,
-			   GtkWidget       *widget,
-			   const gchar     *detail,
-			   gint             x,
-			   gint             y,
-			   const gchar     *string);
+void gtk_draw_string      (GtkStyle           *style,
+			   GdkWindow          *window,
+                           GtkStateType        state_type,
+                           gint                x,
+                           gint                y,
+                           const gchar        *string);
+void gtk_paint_string     (GtkStyle           *style,
+			   GdkWindow          *window,
+			   GtkStateType        state_type,
+			   const GdkRectangle *area,
+			   GtkWidget          *widget,
+			   const gchar        *detail,
+			   gint                x,
+			   gint                y,
+			   const gchar        *string);
 #endif /* GTK_DISABLE_DEPRECATED */
 
-void   gtk_draw_insertion_cursor (GtkWidget        *widget,
-				  GdkDrawable      *drawable,
-				  GdkRectangle     *area,
-				  GdkRectangle     *location,
-				  gboolean          is_primary,
-				  GtkTextDirection  direction,
-				  gboolean          draw_arrow);
-
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+void   gtk_draw_insertion_cursor    (GtkWidget          *widget,
+                                     GdkDrawable        *drawable,
+                                     const GdkRectangle *area,
+                                     const GdkRectangle *location,
+                                     gboolean            is_primary,
+                                     GtkTextDirection    direction,
+                                     gboolean            draw_arrow);
+GdkGC *_gtk_widget_get_cursor_gc    (GtkWidget          *widget);
+void   _gtk_widget_get_cursor_color (GtkWidget          *widget,
+				     GdkColor           *color);
 
+G_END_DECLS
 
 #endif /* __GTK_STYLE_H__ */
