@@ -32,7 +32,6 @@
 #include "gtkvbox.h"
 #include "gtkintl.h"
 #include "gtktoolbar.h"
-#include "gtkiconfactory.h"
 #include "gtkprivate.h"
 #include "gtkalias.h"
 
@@ -95,6 +94,7 @@ struct _GtkToolButtonPrivate
   GtkWidget *icon_widget;
   
   guint use_underline : 1;
+  guint contents_invalid : 1;
 };
 
 GType
@@ -270,6 +270,8 @@ gtk_tool_button_init (GtkToolButton      *button,
   
   button->priv = GTK_TOOL_BUTTON_GET_PRIVATE (button);
 
+  button->priv->contents_invalid = TRUE;
+
   gtk_tool_item_set_homogeneous (toolitem, TRUE);
 
   /* create button */
@@ -295,6 +297,8 @@ gtk_tool_button_construct_contents (GtkToolItem *tool_item)
   GtkWidget *box = NULL;
   guint icon_spacing;
 
+  button->priv->contents_invalid = FALSE;
+
   gtk_widget_style_get (GTK_WIDGET (tool_item), 
 			"icon-spacing", &icon_spacing,
 			NULL);
@@ -488,6 +492,7 @@ gtk_tool_button_set_property (GObject         *object,
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
     }
 }
 
@@ -495,7 +500,10 @@ static void
 gtk_tool_button_property_notify (GObject          *object,
 				 GParamSpec       *pspec)
 {
-  if (strcmp (pspec->name, "is-important") == 0)
+  GtkToolButton *button = GTK_TOOL_BUTTON (object);
+
+  if (button->priv->contents_invalid ||
+      strcmp ("is-important", pspec->name) == 0)
     gtk_tool_button_construct_contents (GTK_TOOL_ITEM (object));
 
   if (parent_class->notify)
@@ -532,6 +540,7 @@ gtk_tool_button_get_property (GObject         *object,
       break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+      break;
     }
 }
 
@@ -605,7 +614,7 @@ gtk_tool_button_create_menu_proxy (GtkToolItem *item)
   gboolean use_mnemonic = TRUE;
   const char *label;
 
-  if (button->priv->label_widget && GTK_IS_LABEL (button->priv->label_widget))
+  if (GTK_IS_LABEL (button->priv->label_widget))
     {
       label = gtk_label_get_label (GTK_LABEL (button->priv->label_widget));
       use_mnemonic = gtk_label_get_use_underline (GTK_LABEL (button->priv->label_widget));
@@ -629,7 +638,7 @@ gtk_tool_button_create_menu_proxy (GtkToolItem *item)
   else
     menu_item = gtk_image_menu_item_new_with_label (label);
 
-  if (button->priv->icon_widget && GTK_IS_IMAGE (button->priv->icon_widget))
+  if (GTK_IS_IMAGE (button->priv->icon_widget))
     {
       menu_image = clone_image_menu_size (GTK_IMAGE (button->priv->icon_widget),
 					  gtk_widget_get_settings (GTK_WIDGET (button)));
@@ -736,13 +745,9 @@ gtk_tool_button_new (GtkWidget	 *icon_widget,
   GtkToolButton *button;
 
   button = g_object_new (GTK_TYPE_TOOL_BUTTON,
+                         "label", label,
+                         "icon-widget", icon_widget,
 			 NULL);
-  
-  if (label)
-    gtk_tool_button_set_label (button, label);
-
-  if (icon_widget)
-    gtk_tool_button_set_icon_widget (button, icon_widget);
 
   return GTK_TOOL_ITEM (button);  
 }
@@ -771,12 +776,11 @@ gtk_tool_button_set_label (GtkToolButton *button,
   old_label = button->priv->label_text;
 
   button->priv->label_text = g_strdup (label);
-  gtk_tool_button_construct_contents (GTK_TOOL_ITEM (button));
-      
-  g_object_notify (G_OBJECT (button), "label");
+  button->priv->contents_invalid = TRUE;     
 
-  if (old_label)
-    g_free (old_label);
+  g_free (old_label);
+ 
+  g_object_notify (G_OBJECT (button), "label");
 }
 
 /**
@@ -826,8 +830,7 @@ gtk_tool_button_set_use_underline (GtkToolButton *button,
   if (use_underline != button->priv->use_underline)
     {
       button->priv->use_underline = use_underline;
-
-      gtk_tool_button_construct_contents (GTK_TOOL_ITEM (button));
+      button->priv->contents_invalid = TRUE;
 
       g_object_notify (G_OBJECT (button), "use-underline");
     }
@@ -875,11 +878,11 @@ gtk_tool_button_set_stock_id (GtkToolButton *button,
   old_stock_id = button->priv->stock_id;
 
   button->priv->stock_id = g_strdup (stock_id);
-  gtk_tool_button_construct_contents (GTK_TOOL_ITEM (button));
-  
-  g_object_notify (G_OBJECT (button), "stock-id");
+  button->priv->contents_invalid = TRUE;
 
   g_free (old_stock_id);
+  
+  g_object_notify (G_OBJECT (button), "stock-id");
 }
 
 /**
@@ -925,11 +928,11 @@ gtk_tool_button_set_icon_name (GtkToolButton *button,
   old_icon_name = button->priv->icon_name;
 
   button->priv->icon_name = g_strdup (icon_name);
-  gtk_tool_button_construct_contents (GTK_TOOL_ITEM (button));
-
-  g_object_notify (G_OBJECT (button), "icon-name");
+  button->priv->contents_invalid = TRUE; 
 
   g_free (old_icon_name);
+
+  g_object_notify (G_OBJECT (button), "icon-name");
 }
 
 /**
@@ -975,22 +978,17 @@ gtk_tool_button_set_icon_widget (GtkToolButton *button,
       if (button->priv->icon_widget)
 	{
 	  if (button->priv->icon_widget->parent)
-	    {
-	      gtk_container_remove (GTK_CONTAINER (button->priv->icon_widget->parent),
+	    gtk_container_remove (GTK_CONTAINER (button->priv->icon_widget->parent),
 				    button->priv->icon_widget);
-	    }
 
 	  g_object_unref (button->priv->icon_widget);
 	}
       
       if (icon_widget)
-	{
-	  g_object_ref_sink (icon_widget);
-	}
+	g_object_ref_sink (icon_widget);
 
       button->priv->icon_widget = icon_widget;
-
-      gtk_tool_button_construct_contents (GTK_TOOL_ITEM (button));
+      button->priv->contents_invalid = TRUE;
       
       g_object_notify (G_OBJECT (button), "icon-widget");
     }
@@ -1021,22 +1019,17 @@ gtk_tool_button_set_label_widget (GtkToolButton *button,
       if (button->priv->label_widget)
 	{
 	  if (button->priv->label_widget->parent)
-	    {
-	      gtk_container_remove (GTK_CONTAINER (button->priv->label_widget->parent),
-				    button->priv->label_widget);
-	    }
+	    gtk_container_remove (GTK_CONTAINER (button->priv->label_widget->parent),
+		    	          button->priv->label_widget);
 	  
 	  g_object_unref (button->priv->label_widget);
 	}
       
       if (label_widget)
-	{
-	  g_object_ref_sink (label_widget);
-	}
+	g_object_ref_sink (label_widget);
 
       button->priv->label_widget = label_widget;
-
-      gtk_tool_button_construct_contents (GTK_TOOL_ITEM (button));
+      button->priv->contents_invalid = TRUE;
       
       g_object_notify (G_OBJECT (button), "label-widget");
     }
