@@ -71,7 +71,6 @@ struct _GtkTooltip
   guint browse_mode_enabled : 1;
   guint keyboard_mode_enabled : 1;
   guint tip_area_set : 1;
-  guint custom_was_reset : 1;
 };
 
 struct _GtkTooltipClass
@@ -279,7 +278,7 @@ gtk_tooltip_set_icon (GtkTooltip *tooltip,
 /**
  * gtk_tooltip_set_icon_from_stock:
  * @tooltip: a #GtkTooltip
- * @stock_id: a stock icon name, or %NULL
+ * @stock_id: a stock id, or %NULL
  * @size: a stock icon size
  *
  * Sets the icon of the tooltip (which is in front of the text) to be
@@ -303,6 +302,33 @@ gtk_tooltip_set_icon_from_stock (GtkTooltip  *tooltip,
     gtk_widget_hide (tooltip->image);
 }
 
+/**
+ * gtk_tooltip_set_icon_from_icon_name:
+ * @tooltip: a #GtkTooltip
+ * @icon_name: an icon name, or %NULL
+ * @size: a stock icon size
+ *
+ * Sets the icon of the tooltip (which is in front of the text) to be
+ * the icon indicated by @icon_name with the size indicated
+ * by @size.  If @icon_name is %NULL, the image will be hidden.
+ *
+ * Since: 2.14
+ */
+void
+gtk_tooltip_set_icon_from_icon_name(GtkTooltip  *tooltip,
+				    const gchar *icon_name,
+				    GtkIconSize  size)
+{
+  g_return_if_fail (GTK_IS_TOOLTIP (tooltip));
+
+  gtk_image_set_from_icon_name (GTK_IMAGE (tooltip->image), icon_name, size);
+
+  if (icon_name)
+    gtk_widget_show (tooltip->image);
+  else
+    gtk_widget_hide (tooltip->image);
+}
+
 /**
  * gtk_tooltip_set_custom:
  * @tooltip: a #GtkTooltip
@@ -323,15 +349,6 @@ gtk_tooltip_set_custom (GtkTooltip *tooltip,
   if (custom_widget)
     g_return_if_fail (GTK_IS_WIDGET (custom_widget));
 
-  /* The custom widget has been updated from the query-tooltip
-   * callback, so we do not want to reset the custom widget later on.
-   */
-  tooltip->custom_was_reset = TRUE;
-
-  /* No need to do anything if the custom widget stays the same */
-  if (tooltip->custom_widget == custom_widget)
-    return;
-
   if (tooltip->custom_widget)
     {
       GtkWidget *custom = tooltip->custom_widget;
@@ -370,8 +387,8 @@ gtk_tooltip_set_custom (GtkTooltip *tooltip,
  * Since: 2.12
  */
 void
-gtk_tooltip_set_tip_area (GtkTooltip   *tooltip,
-			  GdkRectangle *rect)
+gtk_tooltip_set_tip_area (GtkTooltip         *tooltip,
+			  const GdkRectangle *rect)
 {
   g_return_if_fail (GTK_IS_TOOLTIP (tooltip));
 
@@ -423,12 +440,8 @@ gtk_tooltip_reset (GtkTooltip *tooltip)
 {
   gtk_tooltip_set_markup (tooltip, NULL);
   gtk_tooltip_set_icon (tooltip, NULL);
+  gtk_tooltip_set_custom (tooltip, NULL);
   gtk_tooltip_set_tip_area (tooltip, NULL);
-
-  /* See if the custom widget is again set from the query-tooltip
-   * callback.
-   */
-  tooltip->custom_was_reset = FALSE;
 }
 
 static void
@@ -779,12 +792,6 @@ gtk_tooltip_run_requery (GtkWidget  **widget,
     }
   while (*widget);
 
-  /* If the custom widget was not reset in the query-tooltip
-   * callback, we clear it here.
-   */
-  if (!tooltip->custom_was_reset)
-    gtk_tooltip_set_custom (tooltip, NULL);
-
   return return_value;
 }
 
